This crate contains kube-rs compatible bindings for Kubernetes custom resources for the k8up.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
k8up.io/v1
ArchiveBackupCheckPreBackupPodPruneRestoreScheduleSnapshot